@@ -4,8 +4,8 @@ Keytotext converts a list of Keywords to sentences and larger texts
 """
 
 
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
 from .pipeline import pipeline
-from .eval import eval_pipeline
+from .eval import eval
 from .trainer import trainer
